#Licensed Materials - Property of IBM
#
#5724-I63, 5724-H88, 5724-H89, 5655-N02, 5724-J08
# 
#Copyright IBM Corp. 2007 All Rights Reserved.
#
#US Government Users Restricted Rights - Use, duplication or
#disclosure restricted by GSA ADP Schedule Contract with
#IBM Corp.

from java.lang import System
from java.io import File
from com.ibm.ws.install.ifactory.xdadapter import XDContributionAdapter
import thread
import time

##########################
#  Class wxd_cadapter
##########################
class wxd_cadapter:
    def __init__(self):
        self._adapter = XDContributionAdapter()
        self._killThread = 1   #Set 1 to start threading loop, set 0 to kill
        self._progress = 0     #Keeps track of progress returning from adapter class
        invocationResult.setInvocationExitCode(invocationId, invocationResult.UNKNOWN)   #Default to UNKNOWN unless it's set to another result after the installer ran

###############################################################################
#  wxd_cadapter - run method
#  Gets options, executable's path and java path for the contribution.
###############################################################################
    def run( self ):
        methodName="run"
        launcherName="setup.jar"
        osname = System.getProperty("os.name")
        separator = System.getProperty("file.separator")
        try:
            options = invocationData.getOptionsForCurrentPlatform (invocationId)
#           A java null is turned into a Python None value, throw exception if options is not resolved and null is received
            if options is None:
                raise exception
            jythonLogger.logMessage(className, methodName, jythonLogger.getLocaleString("IIPAdapterScript.Options", options))
            self._adapter.setOptions(options)

#           Use install script for XD
            if (osname.find("Windows") != -1):
                launcherName="install.bat"
            else:
                launcherName="install"

            cipSetupjar = invocationData.getContributionAbsolutePathForCurrentPlatform(invocationId) + separator + "wxdcg_package" + separator + launcherName
            f_Setupjar = File(cipSetupjar)

            if (f_Setupjar.exists() and f_Setupjar.isFile()):
                jythonLogger.logMessage(className, methodName, jythonLogger.getLocaleString("IIPAdapterScript.ExecutablePath", cipSetupjar))
                self._adapter.setExecutable(cipSetupjar)
            else:
                executable_path = invocationData.getContributionAbsolutePathForCurrentPlatform(invocationId) + separator + launcherName
                jythonLogger.logMessage(className, methodName, jythonLogger.getLocaleString("IIPAdapterScript.ExecutablePath", executable_path))
                self._adapter.setExecutable(executable_path)

            self._adapter.execute()
            jythonLogger.logMessage(className, methodName, jythonLogger.getLocaleString("IIPAdapterScript.EndExecution"))
        except:
            jythonLogger.logMessage(className, methodName, jythonLogger.getLocaleString("IIPAdapterScript.ExecutionException"))
            self._killThread = 0

###############################################################################
#  wxd_cadapter - setResults method
#  Sets results received from adapter back to IIP installer.
###############################################################################
    def setResults( self ):
        methodName="setResults"
        jythonLogger.logMessage(className, methodName, jythonLogger.getLocaleString("IIPAdapterScript.StartSetResults"))
        try:
            invocationResult.setInvocationMessage(invocationId, self._adapter.getInstallResultMessage())
            invocationResult.setInvocationActualInstallLocation(invocationId, self._adapter.getInstallLocation())
            invocationResult.setInvocationLogfileLocation (invocationId, self._adapter.getInstallLog())
#            invocationResult.setInvocationTracefileLocation (invocationId,self._adapter.getInstallTraceFile())
        except:
            jythonLogger.logMessage(className, methodName, jythonLogger.getLocaleString("IIPAdapterScript.SetResultsException"))
            self._killThread = 0

###############################################################################
#  wxd_cadapter - compareAndSetExitCode method
#  Compares the exit code from the adapter and sets exit code to IIP installer.
###############################################################################
    def compareAndSetExitCode ( self ):
        methodName="compareAndSetExitCode"
        jythonLogger.logMessage(className, methodName, jythonLogger.getLocaleString("IIPAdapterScript.StartSetExitCode"))
        try:
            if self._adapter.getInstallExitCode() == 0:
                invocationResult.setInvocationExitCode(invocationId, invocationResult.SUCCESS)
            elif self._adapter.getInstallExitCode() == 1:
                invocationResult.setInvocationExitCode(invocationId, invocationResult.FAILED)
            elif self._adapter.getInstallExitCode() == 2:
                invocationResult.setInvocationExitCode(invocationId, invocationResult.PARTIAL_SUCCESS)
            elif self._adapter.getInstallExitCode() == 232 or self._adapter.getInstallExitCode() == 1000:
                invocationResult.setInvocationExitCode(invocationId, invocationResult.CANCELLED_BY_USER)
            else:
                invocationResult.setInvocationExitCode(invocationId, invocationResult.UNKNOWN)
            self._killThread = 0
        except:
            invocationResult.setInvocationExitCode(invocationId, invocationResult.UNKNOWN)
            jythonLogger.logMessage(className, methodName, jythonLogger.getLocaleString("IIPAdapterScript.SetExitCodeException"))
            self._killThread = 0

###############################################################################
#  wxd_cadapter - readProgressFromAdapter method
#  Call adapter's API to get current progress from the installer.
###############################################################################
    def readProgressFromAdapter ( self ):
        intCurrentProgress = self._adapter.getCurrentProgress()
        if self._progress < intCurrentProgress:
            self._progress = intCurrentProgress
        return self._progress

###############################################################################
#  wxd_cadapter - getKillThread method
#  Ends the progress reading thread.
###############################################################################
    def getKillThread ( self ):
        return self._killThread

##########################
#  Creates progress thread
##########################
def progressThread(delay, adapter):
    while adapter.getKillThread():
        time.sleep(delay)
        invocationController.getInstallationProgressListener().updateInstallationProgress(adapter.readProgressFromAdapter())        


##########################
#  Main
##########################
className="wxd_cg_cadapter.py"
jythonLogger = invocationController.getJythonLogger()
jythonLogger.logMessage(className, __name__, jythonLogger.getLocaleString("IIPAdapterScript.Start"))
contribution_adapter = wxd_cadapter()
# Start the thread for returning progress
thread.start_new_thread(progressThread,(5, contribution_adapter,))
contribution_adapter.run()
contribution_adapter.setResults()
contribution_adapter.compareAndSetExitCode()
jythonLogger.logMessage(className, __name__, jythonLogger.getLocaleString("IIPAdapterScript.End"))
